<?php
/**
 * Internships block
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/copyleft/gpl.html.
 *
 */

/**
 * Internships block default controller
 *
 * @author     Pablo Pagnone
 * @package    block
 * @subpackage internships
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright  Copyright (c) 2012 CareerArc Group LLC.
 **/

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot.'/blocks/internships/form/connect.php');
require_once($CFG->dirroot.'/blocks/internships/locallib.php');

class block_internships_controller_default extends mr_controller_block {

    /**
     * @var string
     */
    private $secret = null;
    /**
     * @var string
     */
    private $key = null;
    /**
     * @var block_internships_wsclient
     */
    private $client = null;

    public function init() {

        // Require capability to connect to internships.
        require_capability('block/internships:connect', $this->get_context());

        parent::init();

        $client = block_internships_wsclient::instance();
        if ($client === null) {
            print_error('invalidaccess');
        }

        $this->client = $client;
    }

    /**
     * Page to load html from internships or redirect to connect form
     */
    public function view_action() {

        global $CFG, $USER, $PAGE;
        $this->heading->text = '';
        $PAGE->navbar->add(get_string('pluginname', 'block_internships'));

        $what = trim(optional_param('what', null, PARAM_TEXT));
        $where = trim(optional_param('where', null, PARAM_TEXT));
        $url = $this->new_url(array('what' => $what, 'where' => $where));

        // Check if exist user.
        if (!$this->client->sign_in($this->get_userdata_array(), $what, $where)) {

            // User is not registered.
            $status = $this->client->get_status();
            $action = ($status == 'Unregistered') ? 'connect' : 'errorconnect';

            $url->param('action', $action);
            redirect($url); // Redirect to connect to show form connect.
        }

        // Show result in iframe.
        $url_iframe = $this->client->get_redirect_url();
        return $this->output->show_iframe($url_iframe);

    }

    /**
     * Page with form to connect with internships
     */
    public function connect_action() {

        global $PAGE, $USER;
        $this->heading->text = ''; // Without title.
        $PAGE->navbar->add(get_string('pluginname', 'block_internships'));

        $what = optional_param('what', null, PARAM_TEXT);
        $where = optional_param('where', null, PARAM_TEXT);
        $search = ($what !== null) or ($where !== null);
        $what = trim($what);
        $where = trim($where);

        $url = $this->new_url(array('action' => 'connect'));
        $form = new block_internships_form_connect($url, null, 'post', '', 'class=form_connect');
        if ($form->is_validated() && $data_form = $form->get_submitted_data()) {
            $data_ref = $this->get_userdata_array();
            $data_ref['allow_notifications'] = $data_form->allow_notifications;
            // Add where and what if user completed search in block.
            if ($data_form->search) {
                $data_ref['what'] = $what;
                $data_ref['where'] = $where;
            }

            // Connect with enternships.
            if ($this->client->register($data_ref)) {

                // User created, redirect to view_action for get and load html.
                $url->param('action', 'view');
                $url->param('what', $what);
                $url->param('where', $where);
                redirect($url);

            } else {
                // Fail to create user.
                $url->param('action', 'errorconnect');
                redirect($url);
            }
        }

        return $this->output->form_connect($search, $form);
    }

    /**
     * Show error to connect
     */
    public function errorconnect_action() {
        global $PAGE;

        $this->heading->text = '';
        $PAGE->navbar->add(get_string('pluginname', 'block_internships'));

        return $this->output->error_connect();
    }

    /**
     * Array with info about user for send to webservice
     */
    private function get_userdata_array() {

        global $USER;
        $data = array(
                    'first_name' => format_string($USER->firstname),
                    'last_name'  => format_string($USER->lastname),
                    'city'       => format_string($USER->city),
                    'country'    => format_string($USER->country),
                    'email'      => format_string($USER->email)
                );

        if (!empty($USER->institution)) {
            $data['institution'] = format_string($USER->institution);
        }
        return $data;
    }

}