<?php
/**
 * Internships block
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/copyleft/gpl.html.
 *
 */

/**
 * Internships block upgrade
 *
 * @author     Pablo Pagnone
 * @package    block
 * @subpackage internships
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright  Copyright (c) 2012 CareerArc Group LLC.
 **/

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot.'/blocks/internships/block_internships.php');

function xmldb_block_internships_upgrade($oldversion=0) {
    global $DB;

    $dbman = $DB->get_manager();
    $result = true;
    $plugin = 'block_internships';
    if ($result && $oldversion < 2012102214) {
        set_config('internships_api_url', block_internships::DEFAULT_BASE_URL, $plugin);
        upgrade_block_savepoint($result, 2012102214, 'internships');
    }

    if ($result && $oldversion < 2012102215) {
        set_config('key'   , block_internships::DEFAULT_KEY   , $plugin);
        set_config('secret', block_internships::DEFAULT_SECRET, $plugin);
        upgrade_block_savepoint($result, 2012102215, 'internships');
    }

    if ($result && $oldversion < 2012102216) {
        $oldplugin = 'blocks/internships';
        $newplugin = 'block_internships';
        $internships_url     = block_internships::DEFAULT_URL_INTERNSHIPS;
        $internships_api_url = block_internships::DEFAULT_BASE_URL;
        $key                 = block_internships::DEFAULT_KEY;
        $secret              = block_internships::DEFAULT_SECRET;
        $config = get_config($oldplugin);
        if ($config !== false) {
            if (!empty($config->internships_url)) {
                $internships_url = $config->internships_url;
            }
            if (!empty($config->internships_api_url)) {
                $internships_api_url = $config->internships_api_url;
            }
            if (!empty($config->key)) {
                $key = $config->key;
            }
            if (!empty($config->secret)) {
                $secret = $config->secret;
            }
        }
        $newconfig = get_config($newplugin);
        if ($newconfig !== false) {
            if (!empty($newconfig->internships_url)) {
                $internships_url = $newconfig->internships_url;
            }
            if (!empty($newconfig->internships_api_url)) {
                $internships_api_url = $newconfig->internships_api_url;
            }
            if (!empty($newconfig->key)) {
                $key = $newconfig->key;
            }
            if (!empty($newconfig->secret)) {
                $secret = $newconfig->secret;
            }
        }

        set_config('internships_url'    , $internships_url    , $newplugin);
        set_config('internships_api_url', $internships_api_url, $newplugin);
        set_config('key'                , $key                , $newplugin);
        set_config('secret'             , $secret             , $newplugin);
        set_config('cache_last'         , null                , $newplugin);
        set_config('total_internship'   , null                , $newplugin);
        set_config('total_companies'    , null                , $newplugin);

        set_config('internships_url'    , null, $oldplugin);
        set_config('internships_api_url', null, $oldplugin);
        set_config('key'                , null, $oldplugin);
        set_config('secret'             , null, $oldplugin);
        set_config('cache_last'         , null, $oldplugin);
        set_config('total_internship'   , null, $oldplugin);
        set_config('total_companies'    , null, $oldplugin);

        upgrade_block_savepoint($result, 2012102216, 'internships');
    }

    return $result;
}
