<?php
/**
 * Internships block
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/copyleft/gpl.html.
 *
 */

/**
 * Form to connect with internships
 *
 * @author     Pablo Pagnone
 * @author     Darko Miletic
 * @package    block
 * @subpackage internships
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright  Copyright (c) 2012 CareerArc Group LLC.
 **/

defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir.'/formslib.php');

class block_internships_form_connect extends moodleform {

    public function definition() {

        global $USER;
        $mform =& $this->_form;
        $required_text = get_string('required');
        // Firstname.
        $mform->addElement('text',
                           'firstname',
                           get_string('firstname', 'block_internships'),
                           array('readonly' => true, 'size' => 35));
        $mform->setType    ('firstname', PARAM_NOTAGS);
        $mform->setDefault ('firstname', $USER->firstname);
        $mform->setConstant('firstname', $USER->firstname);
        $mform->addRule    ('firstname', $required_text, 'required', null, 'client');

        // Lastname.
        $mform->addElement('text',
                           'lastname',
                           get_string('lastname', 'block_internships'),
                           array('readonly' => true, 'size' => 35));
        $mform->setType    ('lastname', PARAM_NOTAGS);
        $mform->setDefault ('lastname', $USER->lastname);
        $mform->setConstant('lastname', $USER->lastname);
        $mform->addRule    ('lastname', $required_text, 'required', null, 'client');

        // Email.
        $mform->addElement('text',
                           'email',
                           get_string('email', 'block_internships'),
                           array('readonly' => true, 'size' => 35));
        $mform->setType    ('email', PARAM_EMAIL);
        $mform->setDefault ('email', $USER->email);
        $mform->setConstant('email', $USER->email);
        $mform->addRule    ('email', $required_text, 'required', null, 'client');

        // City hidden.
        $mform->addElement ('hidden', 'city', $USER->city);
        $mform->setType    ('city', PARAM_NOTAGS);
        $mform->setConstant('city', $USER->city);

        // Country hidden.
        $mform->addElement ('hidden', 'country', $USER->country);
        $mform->setType    ('country', PARAM_NOTAGS);
        $mform->setConstant('country', $USER->country);

        $what   = optional_param('what', null, PARAM_TEXT);
        $where  = optional_param('where', null, PARAM_TEXT);
        $search = ($what !== null) or ($where !== null);

        $mform->addElement('hidden', 'search', $search);
        $mform->addElement('hidden', 'where', $where);
        $mform->addElement('hidden', 'what', $what);

        // Checkbox for get update.
        $mform->addElement('advcheckbox',
                           'allow_notifications',
                           null,
                           '&nbsp;&nbsp;'.s(get_string('checkbox_getupdate', 'block_internships')),
                           null, // No attributes.
                           array('false', 'true') // Custom values for unchecked / checked.
                          );
        $mform->setDefault('allow_notifications', 'true');

        // Agreement text.
        $a = new stdClass();
        $a->url = get_config('block_internships', 'internships_url');
        $agreement = get_string('checkbox_agree', 'block_internships', $a);
        $mform->addElement('static', 'agree', null, $agreement);

        // Control buttons.
        $buttonarray=array();
        $buttonarray[] = $mform->createElement('submit', 'connect');
        $mform->addGroup($buttonarray, 'buttonar', '', array(''), false);

        // Set id for form and remove class default 'mform'.
        $mform->updateAttributes(array('id' => 'internships_form_connect'));
        $mform->removeAttribute('class');
    }
}