<?php
/**
 * Internships block
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/copyleft/gpl.html.
 *
 */

/**
 * Internships block search form
 *
 * @author     Pablo Pagnone
 * @author     Darko Miletic
 * @package    block
 * @subpackage internships
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright  Copyright (c) 2012 CareerArc Group LLC.
 **/

defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir.'/formslib.php');

class block_internships_form_search extends moodleform {

    public function definition() {
        global $PAGE;

        $mform =& $this->_form;

        $plugin = 'block_internships';
        $default_what = get_string('first_question_default', $plugin);
        $what_label   = get_string('first_question'        , $plugin);
        $mform->addElement('text', 'what', $what_label,
                           array(
                               'id'          => 'internships_what',
                               'placeholder' => s($default_what)
                           )
                          );

        $mform->setType('what', PARAM_TEXT);
        $mform->applyFilter('what', 'trim');

        $default_where = get_string('second_question_default', $plugin);
        $where_label   = get_string('second_question', $plugin);
        $mform->addElement('text', 'where', $where_label,
                           array(
                               'id'          => 'internships_where',
                               'placeholder' => s($default_where)
                           )
                          );

        $mform->setType('where', PARAM_TEXT);
        $mform->applyFilter('where', 'trim');

        // Control buttons.
        $buttonarray=array();
        $buttonarray[] = $mform->createElement('submit', 'search', '');
        $mform->addGroup($buttonarray, 'buttonar', '', array(' '), false);

        // Set id for form and remove class default 'mform'.
        $mform->updateAttributes(array('id' => 'internships_form_search'));
        $mform->removeAttribute('class');

        // HTML5 placeholder support.
        $zui_module = array(
                          'name'      => 'gallery-zui-placeholder',
                          'fullpath'  => '/blocks/internships/jslibs/gallery-zui-placeholder/gallery-zui-placeholder.js',
                          'requires'  => array('node-base', 'event-focus', 'node-event-delegate'),
                          'strings'   => array()
                      );
        $PAGE->requires->js_module($zui_module);

        // Validation js.
        $module = array(
                      'name'      => 'block_internships',
                      'fullpath'  => '/blocks/internships/module.js',
                      'requires'  => array('base', 'node', 'event', 'gallery-zui-placeholder'),
                      'strings'   => array(
                              array('search_error'           , $plugin),
                              array('first_question_default' , $plugin),
                              array('second_question_default', $plugin)
                      )
                  );
        $PAGE->requires->js_init_call('M.block_internships.initsearch', null, true, $module);
    }
}
