<?php
/**
 * Internships block
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/copyleft/gpl.html.
 *
 */

/**
 * Renderer
 * @author     Pablo Pagnone
 * @package    block
 * @subpackage internships
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @copyright  Copyright (c) 2012 CareerArc Group LLC.
 */

defined('MOODLE_INTERNAL') or die();

require_once(__DIR__.'/form/search.php');

class block_internships_renderer extends plugin_renderer_base {

    /**
     * Block content with form
     * @param integer $total_internship
     * @param integer $total_companies
     * @param block_internships_form_search $mform
     */
    public function block_content($total_internship, $total_companies, block_internships_form_search $mform) {

        $output = '';

        // First block - values.
        $desc1 = html_writer::tag('span', get_string('internships_from', 'block_internships'), array('class' => 'pvalues_desc'));
        $desc2 = html_writer::tag('span', get_string('companies', 'block_internships'), array('class' => 'pvalues_desc'));

        $number1 = html_writer::tag('span', number_format($total_internship), array('class' =>'pvalues_number'));
        $number2 = html_writer::tag('span', number_format($total_companies), array('class' =>'pvalues_number'));

        $content_values = html_writer::tag('p', $number1.$desc1, array('class' => 'pvalues'));
        $content_values .= html_writer::tag('p', $number2.$desc2, array('class' => 'pvalues'));
        $output .= html_writer::tag('div', $content_values, array('class' => 'values'));
        // End first block - values.

        // Second block.
        $output .= html_writer::start_tag('div', array('class' => 'internships_contentblock'));
        $output .= html_writer::tag('div', get_string('subtitle_block', 'block_internships'), array('class' => 'blue_subtitle'));
        // End second block.

        // Form.
        $form = mr_helper::get('blocks/internships')->buffer(array($mform, 'display'));
        $output .= html_writer::tag('div', $form, array('class' => 'form_style'));

        $output .= html_writer::end_tag('div');
        return $output;
    }

    /**
     * Form to connect with internships
     * @param boolean $from_search
     * @param block_internships_form_connect $mform
     */
    public function form_connect($from_search = true, block_internships_form_connect $mform) {
        global $PAGE, $CFG;

        $output = '';
        $output .= html_writer::start_tag('div', array('id' => 'internships_connect'));

        // Show header image.
        $output .= html_writer::start_tag('div', array('id' => 'internships_connect_header'));
        $output .= html_writer::empty_tag('img',
                     array('src' => $CFG->wwwroot.'/blocks/internships/pix/connect_header.png',
                           'alt' => s(get_string('pluginname', 'block_internships'))));
        $output .= html_writer::end_tag('div');

        if ($from_search) {
            $PAGE->set_title(get_string('instructional1', 'block_internships'));
            $output .= $this->output->heading(s(get_string('instructional1', 'block_internships')), 1);
            $output .= $this->output->heading(s(get_string('instructional1b', 'block_internships')), 3);
        } else {
            $PAGE->set_title(s(get_string('instructional2', 'block_internships')));
            $output .= $this->output->heading(s(get_string('instructional2', 'block_internships')), 1);
        }

        // Form.
        $form = mr_helper::get('blocks/internships')->buffer(array($mform, 'display'));
        $output .= html_writer::tag('div', $form, array('class' => 'form_connect'));
        $output .= html_writer::end_tag('div');

        return $output;
    }

    /**
     * Page error connect
     */
    public function error_connect() {

        global $CFG;
        $output = '';

        $output .= html_writer::start_tag('div', array('id' => 'internships_error_connect'));
        $output .= html_writer::tag('img', '', array('src' => $CFG->wwwroot.'/blocks/internships/pix/error.png',
                                    'class' => 'img_error'));
        $output .= html_writer::tag('h1', get_string('error_connect1', 'block_internships'));
        $output .= html_writer::tag('h3', get_string('error_connect2', 'block_internships'));
        $output .= html_writer::tag('p', get_string('error_connect3', 'block_internships'));
        $output .= html_writer::end_tag('div');

        return $output;
    }

    /**
     * show iframe
     * @param string $src
     * @return string
     */
    public function show_iframe($src, $width='100%', $height='1150px') {
        global $CFG;
        $output = '';
        $output .= html_writer::tag('iframe', '',
                                    array('id' => 'iframe_internships',
                                          'src' => $src,
                                          'width' => $width,
                                          'height' => $height));

        return $output;
    }
}